package es2;

/**
 * Interfaccia per implementare ordini parziali nello stile di Comparable
 * 
 * @author Stefano Guerrini
 * @version giugno 2009
 */

public interface ParzOrdinabile<T>
{
    /**
     * Verifica se due oggetti sono confrontabili rispetto a un ordine parziale
     * definito dalla classe che implementa l'interfaccia 
     * 
     * @param  o    oggetto da confrontare con l'istanza che riceve il messaggio
     * @return      true se gli oggetti sono confrontabili, ovvero o e' minore,
     *              maggiore o uguale dell'oggetto che riceve il messaggio
     *              false se gli oggetti sono inconfrontabili, ovvero
     *              non sono in relazione
     */
    public boolean confrontabileCon(T o);

    /**
     * Confronta due oggetti rispetto all'ordine parziale definito dalla classe
     * che implementa l'interfaccia 
     * 
     * @param  o    oggetto da confrontare con l'istanza che riceve il messaggio
     * @return      restituisce un intero negativo se o e' maggiore dell'oggetto,
     *              che riceve il messaggio, un intero positivo se o e'minore, 0
     *              se gli oggetti sono uguali
     *              solleva l'eccezione OggettiInconfrontabiliException se i due 
     *              oggetti sono inconfrontabili
     */
    public int confrontaCon(T o) throws OggettiInconfrontabiliException;
}
