package es2;

/**
 * Interfaccia per implementare ordini parziali nello stile di Comparator
 * 
 * @author Stefano Guerrini
 * @version giugno 2009
 */

public interface ParzOrdinatore<T>
{
    /**
     * Verifica se due oggetti sono confrontabili rispetto a un ordine parziale
     * definito dalla classe che implementa l'interfaccia 
     * 
     * @param  o1, o2   oggetti da confrontare
     * @return          true se gli oggetti sono confrontabili, ovvero o1 e' minore,
     *                  maggiore o uguale di o2
     *                  false se gli oggetti sono inconfrontabili, ovvero
     *                  non sono in relazione
     */
    public boolean confrontabili(T o1, T o2);

    /**
     * Confronta due oggetti rispetto all'ordine parziale definito dalla classe
     * che implementa l'interfaccia 
     * 
     * @param  o1, o2   oggetti da confrontare
     * @return          restituisce un intero negativo se o1 e' maggiore di o2,
     *                  un intero positivo se o1 e' minore di o2, 0
     *                  se gli oggetti sono uguali
     *                  solleva l'eccezione OggettiInconfrontabiliException se i due 
     *                  oggetti sono inconfrontabili
     */
    public int confronta(T o1, T o2) throws OggettiInconfrontabiliException;
}
