package es2;

/**
 * Implementazione della classe ParzOrdinabile come ordine parziale di stringhe
 * rispetto alla relazione di prefisso
 * 
 * @author Stefano Guerrini 
 * @version giugno 2009
 */
public class PrefixParzOrdString extends MyString implements ParzOrdinabile<MyString> {

    /**
     * Construttore della classe
     * 
     * @param str      la stringa da memorizzare
     * 
     */
    public PrefixParzOrdString(String str)
    {
        super(str);
    }
    
    /**
     * Verifica se due stringhe sono confrontabili rispetto all'ordine parziale
     * di prefisso
     * 
     * @param  str  stringa da confrontare con l'istanza che riceve il messaggio
     * @return      true se le strighe sono confrontabili, ovvero str e' minore,
     *              maggiore o uguale della stringa che riceve il messaggio
     *              false se le stringhe sono inconfrontabili, ovvero
     *              non sono in relazione
     */
    public boolean confrontabileCon(MyString str) {
        return (get().startsWith(str.get()) || str.get().startsWith(get()));
    }

    /**
     * Confronta due stringhe rispetto all'ordine parziale di prefisso
     * 
     * @param  str  stringa da confrontare con l'istanza che riceve il messaggio
     * @return      restituisce un intero negativo se str e' maggiore dell'istanza
     *              che riceve il messaggio, un intero positivo se str e'minore, 0
     *              se sono uguali
     *              solleva l'eccezione OggettiInconfrontabiliException se le due 
     *              strighe sono inconfrontabili
     */
    public int confrontaCon(MyString str) throws OggettiInconfrontabiliException {
        if (get().equals(str.get())) {
            return 0;
        } else if (get().startsWith(str.get())) {
            return 1;
        } else if (str.get().startsWith(get())) {
            return -1;
        } else {
            String msg = "Tentativo di confrontare due stringhe inconfrontabili.\n"
                            + "La stringa " + str.get()
                            + "non e' confrontabile con la stringa "
                            + get();
            throw(new OggettiInconfrontabiliException(msg));
        }
    }
}
