package es2;

/**
 * Implementazione della classe ParzOrdinatore come ordine parziale du stringhe
 * rispetto alla relazione di prefisso
 * 
 * @author Stefano Guerrini 
 * @version giugno 2009
 */
public class PrefixStringOrdinatore extends MyString implements ParzOrdinatore<MyString> {

    /**
     * Construttore della classe
     * 
     * @param str      la stringa da memorizzare
     * 
     */
    public PrefixStringOrdinatore(String str)
    {
        super(str);
    }

    /**
     * Verifica se due oggetti sono confrontabili rispetto a un ordine parziale
     * definito dalla classe che implementa l'interfaccia 
     * 
     * @param  str1, str2   stringhe da confrontare
     * @return              true se le stringhe sono confrontabili, ovvero str1 e'
     *                      minore, maggiore o uguale di str2
     *                      false se le stringhe non sono confrontabili, ovvero
     *                      non sono in relazione
     */
    public boolean confrontabili(MyString str1, MyString str2) {
        return (str1.get().startsWith(str2.get())
                || str2.get().startsWith(str1.get()));
    }

    /**
     * Confronta due stringhe rispetto all'ordine parziale di prefisso
     * 
     * @param  str1, str2   stringhe da confrontare
     * @return              restituisce un intero negativo se str1 e' maggiore
     *                      di str2, un intero positivo se str1 e'minore di str2,
     *                      0 se le stringhe sono uguali
     *                      solleva l'eccezione OggettiInconfrontabiliException se
     *                      le due stringhe sono inconfrontabili
     */
    public int confronta(MyString str1, MyString str2)
                        throws OggettiInconfrontabiliException {
        if (str1.get().equals(str1.get())) {
            return 0;
        } else if (str1.get().startsWith(str2.get())) {
            return 1;
        } else if (str2.get().startsWith(str1.get())) {
            return -1;
        } else {
            String msg = "Tentativo di confrontare due stringhe inconfrontabili.\n"
                            + "La stringa " + str2.get()
                            + "non e' confrontabile con la stringa "
                            + str1.get();
            throw(new OggettiInconfrontabiliException(msg));
        }
    }
}
