package es3bis;

/**
 * Implementazione di coppie senza ordine tra gli elementi.
 * 
 * @author Stefano Guerrini
 * @version giugno 2009
 */
public class Pair<T extends Cloneable> {
    // gli elementi della coppia
    private T fst, snd;

    /**
     * Costruttore di oggetto della classe Pair
     */
    public Pair(T f, T s, Clonator<T> o) {
        fst = o.clonator(f);
        snd = o.clonator(s);
    }
    
    /**
     * primo elemento della coppia
     */
    public T first() {
        return fst;
    }
    
    /**
     * secondo elemento della coppia
     */
    public T second() {
        return snd;
    }
    
    /**
     * Metodo equals interno che confronta con un oggetto di tipo Pair<T>
     * Chiamato dal metodo che comfornta con un object
     */
    private boolean equals(Pair<T> p) {
        if (p.getClass() == this.getClass()) {
            return (p.first().equals(fst) && p.second().equals(snd))
                        || (p.first().equals(snd) && p.second().equals(fst));
        }
        return false;
    }
    
    /**
     * Riscrive equals in modo che due coppie siano uguali indipendentemente
     * dall'ordine degli elementi
     */
    public boolean equals(Object o) {
        return equals((Pair<T>)o);
    }

    /**
     * Riscrive hashCode coerentemente con la ridefinizione di equals
     * Prende la somma degli hashCode dei due elementi
     * Evidentmente, la somma e' indipendente dall'ordine degli elementi
     */
    public int hashCode() {
        return fst.hashCode() + snd.hashCode();
    }

}
